Please see [https://docs.mlcommons.org/cm4mlops/scripts//save-mlperf-inference-implementation-state](https://docs.mlcommons.org/cm4mlops/scripts//save-mlperf-inference-implementation-state) for the documentation of this CM script.
